// gwFunctions.js -- JavaScript functions for Ground-water Tutor
// author: Geoff Bohling
// created: 18-June-03
// last modified:  16-November-03

// borrowed from the Rhino book . . .
// constructor function creates a Cookie object
//   document:  the Document object for which the cookie is stored
//   name:      name of the cookie
//   hours:     hours until expiration
function Cookie(document,name,hours)
{
    // predefined properties start with $ to distinguish from data properties
    this.$document = document;
    this.$name = name;
    if (hours) {
        this.$expiration = new Date((new Date()).getTime() + hours*3600000);
    } else {
        this.$expiration = null;
    }
}

Cookie.prototype.store = function() {
    var cookieval="";
    for (var prop in this) {
        if ( (prop.charAt(0)=='$') || ( (typeof this[prop]) == 'function' ) )
             continue;
        if (cookieval != "") cookieval += '&';
        cookieval += prop + ':' + escape(this[prop]);
    }
    var cookie = this.$name + '=' + cookieval;
    if (this.$expiration)
        cookie += '; expires=' + this.$expiration.toGMTString();
    this.$document.cookie = cookie;
}

Cookie.prototype.load = function() {
    var allcookies = this.$document.cookie;
    if (allcookies == "") return false;
    var start = allcookies.indexOf(this.$name + '=');
    if (start == -1) return false;
    start += this.$name.length + 1;
    var end = allcookies.indexOf(';',start);
    if (end == -1) end = allcookies.length;
    var cookieval = allcookies.substring(start,end);

    var a = cookieval.split('&')
    for (var i=0; i < a.length; i++) {
        a[i] = a[i].split(':');
    }
    for (var i=0; i < a.length; i++) {
        this[a[i][0]] = unescape(a[i][1]);  // treating this as associative array
    }
    return true;
}

// following added 16-November-03
function getPorosities(document) {
  porosities = new Cookie(document,"porosities",240);
  if ( !porosities.load() ) {
      porosities.por01="";
      porosities.por02="";
      porosities.por03="";
      porosities.por04="";
      porosities.por05="";
      porosities.por06="";
   }
   return porosities;
}

function getCalcVals(document) {
  calcvals = new Cookie(document,"calcvals",240);
  if ( !calcvals.load() ) {
      calcvals.hyCond = "";
      calcvals.hyGrad = "";
      calcvals.loPor = "";
      calcvals.hiPor = "";
      calcvals.loVel = "";
      calcvals.hiVel = "";
      calcvals.startDate = "";
      calcvals.endDate = "";
      calcvals.curDate = "";
      calcvals.leadTime = "";
      calcvals.trailTime = "";
      calcvals.minLeadDist = "";
      calcvals.maxLeadDist = "";
      calcvals.minTrailDist = "";
      calcvals.maxTrailDist = "";
  }
  return calcvals;
}

function roundit(a,b) // returns a rounded to b digits
{
    c = b - Math.round(0.5 + (Math.log(a)/Math.log(10)))
    c = Math.pow(10,c)
    c = Math.round(c*a)/c
    return c
}

var glossWindow;
function gloss(entry) {
   // opens (or re-opens) glossary window to appropriate entry
   if (!glossWindow || glossWindow.closed) {
       glossWindow = window.open("gwGlossary.html#" + entry,"GlossWindow","status,scrollbars,resizable,height=400,width=750");
       glossWindow.focus();
   } else {
       glossWindow = window.open("gwGlossary.html#" + entry,"GlossWindow");
       glossWindow.focus();
   }
}

var aboutWindow;
function about(topicPage) {
   // opens (or re-opens) about window with appropriate topic page
   if (!aboutWindow || aboutWindow.closed) {
       aboutWindow = window.open(topicPage,"AboutWindow","status,scrollbars,resizable,height=500,width=850");
       aboutWindow.focus();
   } else {
       aboutWindow = window.open(topicPage,"AboutWindow");
       aboutWindow.focus();
   }
}

var pictureWindow;
function openPicture(picturePage) {
   // opens (or re-opens) picture window with appropriate picture page
   if (!pictureWindow || pictureWindow.closed) {
       pictureWindow = window.open(picturePage,"PictureWindow","status,scrollbars,resizable,height=500,width=850");
       pictureWindow.focus();
   } else {
       pictureWindow = window.open(picturePage,"PictureWindow");
       pictureWindow.focus();
   }
}

var calcWindow;
function openCalc() {
   // opens (or re-opens) calculator window
   if (!calcWindow || calcWindow.closed) {
       calcWindow = window.open("gwCalculator.html","calcWindow","status,scrollbars,resizable,height=450,width=800");
       calcWindow.focus();
   } else {
       calcWindow.focus();
   }
}

var tourWindow;
function openTour() {
   // opens (or re-opens) site tour window
   if (!tourWindow || tourWindow.closed) {
       tourWindow = window.open("gwSiteTour01.html","TourWindow","status,scrollbars,resizable,height=550,width=900");
       tourWindow.focus();
   } else {
       tourWindow.focus();
   }
}

var audioWindow;
function play(audiofile) {
   // fires up audiofile in the audio window and hopefully hides it . . .
   var Content = "<html><head><title>Audio Window</title></head><body><embed src='audio/" + audiofile + "' autoplay=true loop=false></embed></body></html>";
   audioWindow = window.open("","AudioWindow","status,scrollbars,resizable,height=100,width=300");
   audioWindow.document.write(Content);
   audioWindow.document.close();
   audioWindow.blur();
}

